( cd usr/lib ; rm -rf libdbus-glib-1.so )
( cd usr/lib ; ln -sf libdbus-glib-1.so.2.2.2 libdbus-glib-1.so )
( cd usr/lib ; rm -rf libdbus-glib-1.so.2 )
( cd usr/lib ; ln -sf libdbus-glib-1.so.2.2.2 libdbus-glib-1.so.2 )
( cd usr/doc/dbus-glib-0.100.2 ; rm -rf html )
( cd usr/doc/dbus-glib-0.100.2 ; ln -sf ../../share/gtk-doc/html/dbus-glib/ html )
